#!/bin/bash -e

wd=$(pwd)
jobid=$(squeue --me | head -2 | tail -n1 | awk '{print $1}')


#
# Example assume allocation was created, e.g.:
# N=1 ; salloc -p standard-g  --threads-per-core 1 --exclusive -N $N --gpus $((N*8)) -t 4:00:00 --mem 0
#

module purge
module load CrayEnv
module load PrgEnv-cray/8.3.3
module load craype-x86-trento
module load craype-accel-amd-gfx90a

module use /pfs/lustrep2/projappl/project_462000125/samantao-public/mymodules
module load rocm/5.6.1.lua

set -x

# Install pytorch if it doesn't exist already.
if [ ! -d $wd/miniconda3/envs/pytorch ] ; then
    curl -LO https://repo.anaconda.com/miniconda/Miniconda3-py310_24.1.2-0-Linux-x86_64.sh
    bash ./Miniconda3-* -b -p $wd/miniconda3 -s
    rm -rf ./Miniconda3-*

    source $wd/miniconda3/bin/activate base
    conda create -y -n pytorch python=3.10
    source $wd/miniconda3/bin/activate pytorch
    pip3 install --pre torch==2.2.2+rocm5.6 --index-url https://download.pytorch.org/whl/
else
    source $wd/miniconda3/bin/activate pytorch
fi

srun --jobid=$jobid -n1 --gpus 8 \
    python -c 'import torch; print("I have this many devices:", torch.cuda.device_count())'
